import { useGlobalModalServices } from '@/pages/GlobalModalServices/provider';
import { formatNumber } from '@/utils/ui';
import { CaretDownOutlined } from '@ant-design/icons';
import { Progress, Statistic, StatisticProps } from 'antd';
import { useMemo } from 'react';
import CountUp from 'react-countup';
import styles from './index.less';
import LineCharts from './LineCharts';
const formatter: StatisticProps['formatter'] = (value: any) => {
  return (
    <CountUp
      end={formatNumber(value)?.num as number}
      separator=""
      decimals={formatNumber(value)?.unit == '万件' ? 2 : 0}
    />
  );
};
const OperatingSituation = () => {
  const { dispatch } = useGlobalModalServices();
  const platformList = useMemo(() => {
    return [
      {
        key: '1',
        name: '市城运平台',
        value: 1208,
        unit: '件',
        lineData: [10, 80, 19, 30, 40, 50],
        onClick: () => {
          dispatch?.push('UrbanOperation' as any, {
            title: '智慧蓉城提级通道处置情况',
            props: {
              type: 'UrbanOperation',
              title: '智慧蓉城提级通道处置情况',
              eventType: '5',
            },
          });
        },
      },
      {
        key: '2',
        name: '12345市民投诉',
        value: 1208,
        unit: '件',
        lineData: [10, 80, 19, 30, 40, 50],
      },
      {
        key: '3',
        name: '数字城管',
        value: 1208,
        unit: '件',
        lineData: [10, 80, 19, 30, 40, 50],
      },
      {
        key: '4',
        name: '突出问题推送',
        value: 1208,
        unit: '件',
        lineData: [10, 80, 19, 30, 40, 50],
        onClick: () => {
          dispatch?.push('CgftEvent' as any, {
            title: '诚管24高速通道处置情况',
            props: {
              type: 'CgftEvent',
              title: '诚管24高速通道处置情况',
              singleType: '1',
            },
          });
        },
      },
      {
        key: '5',
        name: '行走成都',
        value: 1208,
        unit: '件',
        lineData: [10, 80, 19, 30, 40, 50],
        onClick: () => {
          dispatch?.push('CollectionEvent' as any, {
            title: '行走成都事件',
            props: {
              type: 'CollectionEvent',
              title: '行走成都事件',
              collectionMode: '4',
            },
          });
        },
      },
      {
        key: '6',
        name: '委内业务系统',
        value: 1208,
        unit: '件',
        lineData: [10, 80, 19, 30, 40, 50],
      },
    ];
  }, [dispatch]);
  return (
    <div className={styles.container}>
      <div className={styles.titleWarp}>
        <div className={styles.title}>运行态势</div>
        {/* <div className={styles.select}>本月</div> */}
      </div>
      <div className={styles.content}>
        <div className={styles.platform}>
          {platformList?.map((item) => {
            return (
              <div
                className={styles.platItem}
                key={item?.key}
                onClick={() => {
                  item?.onClick?.();
                }}
              >
                <div className={styles.title}>{item?.name}</div>
                <LineCharts
                  data={item?.lineData}
                  style={{ width: 126, height: 30 }}
                />

                <div className={styles.countWarp}>
                  <Statistic
                    valueStyle={{ fontSize: 36, lineHeight: 1 }}
                    value={item.value}
                    formatter={formatter}
                  />
                  <span className={styles.unit}>{item?.unit}</span>
                </div>
              </div>
            );
          })}
        </div>
        <img
          src={require('@/assets/images/tljt.png')}
          alt=""
          style={{ marginTop: 10 }}
        />
        <div className={styles.rigth}>
          <div className={styles.topWarp}>
            <div className={styles.title}>城市管理综合问题总数</div>
            <div
              className={styles.countWarp}
              style={{ cursor: 'pointer' }}
              onClick={() => {
                dispatch.push('GeneralSituation', {
                  title: '事件总体情况',
                });
              }}
            >
              <Statistic
                valueStyle={{ fontSize: 38, lineHeight: 1 }}
                value={1208}
                formatter={formatter}
              />
              <span className={styles.unit}>件</span>
            </div>
          </div>
          <div className={styles.roat}>
            <span>环比</span>
            <span>
              {/* <CaretUpOutlined style={{ color: 'red' }} /> */}
              <CaretDownOutlined style={{ color: 'rgb(29, 187, 138)' }} />
            </span>
            <span className={styles.count}>0.25</span>
            <span>%</span>
          </div>

          <LineCharts
            data={[10, 29, 10, 49, 20, 30, 50, 19]}
            style={{ width: '100%', height: 64 }}
          />
          <div className={styles.eventWarp}>
            <div className={styles.eventItem}>
              <img
                src={require('@/assets/images/evtIc1.png')}
                alt=""
                className={styles.icon}
              />
              <div className={styles.rw}>
                <div className={styles.countWarp}>
                  <Statistic
                    valueStyle={{ fontSize: 30, lineHeight: 1 }}
                    value={187}
                    formatter={formatter}
                  />
                  <span className={styles.unit}>件</span>
                </div>
                <div className={styles.label}>立案</div>
              </div>
            </div>
            <div className={styles.eventItem}>
              <img
                src={require('@/assets/images/evtIc3.png')}
                alt=""
                className={styles.icon}
              />
              <div className={styles.rw}>
                <div className={styles.countWarp}>
                  <Statistic
                    valueStyle={{ fontSize: 30, lineHeight: 1 }}
                    value={187}
                    formatter={formatter}
                  />
                  <span className={styles.unit}>件</span>
                </div>
                <div className={styles.label}>应处置</div>
              </div>
            </div>
            <div className={styles.eventItem}>
              <img
                src={require('@/assets/images/evtIc2.png')}
                alt=""
                className={styles.icon}
              />
              <div className={styles.rw}>
                <div className={styles.countWarp}>
                  <Statistic
                    valueStyle={{ fontSize: 38, lineHeight: 1 }}
                    value={142}
                    formatter={formatter}
                  />
                  <span className={styles.unit}>件</span>
                </div>
                <div className={styles.label}>已结案</div>
              </div>
            </div>
            <div
              className={styles.eventItem}
              style={{ cursor: 'pointer' }}
              onClick={() => {
                dispatch.push('ToDisposed', {
                  title: '待处置事件',
                });
              }}
            >
              <img
                src={require('@/assets/images/evtIc4.png')}
                alt=""
                className={styles.icon}
              />
              <div className={styles.rw}>
                <div className={styles.countWarp}>
                  <Statistic
                    valueStyle={{ fontSize: 30, lineHeight: 1 }}
                    value={87}
                    formatter={formatter}
                  />
                  <span className={styles.unit}>件</span>
                </div>
                <div className={styles.label}>处置中</div>
              </div>
            </div>
          </div>

          <div className={styles.issueWarp}>
            <div className={styles.topWarp}>
              <div className={styles.title}>疑难问题</div>
              <div className={styles.countWarp}>
                <Statistic
                  valueStyle={{ fontSize: 30, lineHeight: 1 }}
                  value={2687}
                  formatter={formatter}
                />
                <span className={styles.unit}>件</span>
              </div>
            </div>

            <div className={styles.progressWarp}>
              <Progress
                percent={100}
                size={{ height: 20 }}
                success={{ percent: 60 }}
                showInfo={false}
                strokeColor="rgb(255, 95, 95)"
              />
            </div>
            <div className={styles.botWarp}>
              <div
                className={styles.item}
                style={{ cursor: 'pointer' }}
                onClick={() => {
                  dispatch.push('DifficultEvents', {
                    title: '疑难案件',
                  });
                }}
              >
                <div
                  className={styles.dot}
                  style={{ background: 'rgb(255, 198, 20)' }}
                ></div>
                <span className={styles.name}>城市管理类</span>
                <Statistic
                  valueStyle={{ fontSize: 24, lineHeight: 1 }}
                  value={1587}
                  formatter={formatter}
                />
                <span className={styles.unit}> 件</span>
              </div>
              <div
                className={styles.item}
                style={{ cursor: 'pointer' }}
                onClick={() => {
                  dispatch.push('DifficultEvents', {
                    title: '疑难案件',
                  });
                }}
              >
                <div
                  className={styles.dot}
                  style={{ background: 'rgb(255, 95, 95)' }}
                ></div>
                <span className={styles.name}>其它</span>
                <Statistic
                  valueStyle={{ fontSize: 24, lineHeight: 1 }}
                  value={587}
                  formatter={formatter}
                />
                <span className={styles.unit}> 件</span>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default OperatingSituation;
